/**
** This software is distributed under the terms of the General Public License.  
** 
** Program : BuildIT!
** Version : 0.2
** Authors : Artur Prusakiewicz <prusak@mat.uni.torun.pl>
**	     Michal Switala <scisly@mat.uni.torun.pl>
** E-MAIL  : build@mat.uni.torun.pl
** WWW     : http://www.mat.uni.torun.pl/~scisly/buildit/
**           http://www.mat.uni.torun.pl/~prusak/buildit/
**/

#include "ShowTree.h"

ShowTree::ShowTree(MyTree *t, QString sysdirectory, int st)
{
  style = st;
  treetab = t;
  sysDir = sysdirectory.copy();
}

bool ShowTree::updateTreePic(MyTree *t, QListViewItem *lv)
{
  QString name=t->GetFeature1(1)->copy();
  name = name.right(name.length()-name.findRev(" ")-1);
  QString widclass = t->GetFeature1(2)->copy();
  QPixmap *icon;
  if (widclass == "MyClass")
    if (t->GetFeature2(20) == 15)
      widclass = "Applet";
    else
      widclass = "Frame";
  if (widclass == "MyCanvas") 
    {
      widclass = "Canvas"; 
      icon = new QPixmap(sysDir+"images/canvas_i.xpm");
    }
  if (widclass == "MyChoice") 
    {
      widclass = "Choice";
      icon = new QPixmap(sysDir+"images/choice_i.xpm");
    }
  if (widclass == "MyLabel") 
    {
      widclass = "Label";
      icon = new QPixmap(sysDir+"images/label_i.xpm");
    }
  if (widclass == "MyList") 
    {
      widclass = "List";
      icon = new QPixmap(sysDir+"images/list_i.xpm");
    }
  if (widclass == "MyMenuBar") 
    {
      widclass = "MenuBar";
      icon = new QPixmap(sysDir+"images/menu_i.xpm");
    }
  if (widclass == "MyMenu")	
    {
      widclass = "Menu";
      icon = new QPixmap(sysDir+"images/menu_item_i.xpm");
    }
  if (widclass == "MyPushButton") 
    {
      widclass = "Button";
      icon = new QPixmap(sysDir+"images/button_i.xpm");
    }
  if (widclass == "MyRadioButton") 
    {
      widclass = "Checkbox";
      icon = new QPixmap(sysDir+"images/checkbox_i.xpm");
    }
  if (widclass == "MyScrollBar") 
    {
      widclass = "Scrollbar";
      icon = new QPixmap(sysDir+"images/scroll_i.xpm");
    }
  if (widclass == "MyTextArea") 
    {
      widclass = "TextArea";
      icon = new QPixmap(sysDir+"images/text_area_i.xpm");
    }
  if (widclass == "MyTextField") 
    {
      widclass = "TextField";
      icon = new QPixmap(sysDir+"images/text_i.xpm");
    }
  if (widclass == "subMenu")  
    {
      widclass = "SubMenu";
      name = t->GetFeature1(3)->copy();
      icon = new QPixmap(sysDir+"images/menusub_i.xpm");
    }
  if (widclass == "ChoiceItem") 
    {
      name = t->GetFeature1(3)->copy();
      icon = new QPixmap(sysDir+"images/choice_i.xpm");
    }
  if (widclass == "ListItem") 
    {
      name = t->GetFeature1(3)->copy();
      icon = new QPixmap(sysDir+"images/list_i.xpm");
    }
  if (widclass == "MenuItem")
	{
	  if (t->GetFeature1(3)->isEmpty() == TRUE)
	    {
	      name = "----";
	      icon = new QPixmap(sysDir+"images/menu_i.xpm");
	    }
	  else
	    if (t->GetFeature2(22) == 1)
	      {
		name = t->GetFeature1(3)->copy();
		icon = new QPixmap(sysDir+"images/menuch_i.xpm");
	      }
	    else
	      {
		name = t->GetFeature1(3)->copy();
		icon = new QPixmap(sysDir+"images/menu_i.xpm");
	      }
	}
  QListViewItem *current = new QListViewItem(lv, name.data(), (QString("| ").append(widclass.data())).data(),(QString( "| ").append(t->GetFeature1(3)->data())).data());
  if ((widclass != "Applet") && (widclass != "Frame"))
    {
      current->setOpen(FALSE);
      current->setPixmap(0,*icon);
    }
  else 
    current->setOpen(TRUE);
  int numch = t->GetNumChildren();
  if (numch)
    for (int i = 0; i < numch; i++)
      updateTreePic(t->GetChildren(i), current);
  return TRUE;
}


void ShowTree::displayTree(bool first)
{ 
  int ty = 5;
  mainframe = new QFrame(NULL, "main_frame");
  if (first != TRUE) 
    mainframe->setGeometry(wx, wy, 520, 450);
  mainframe->setMinimumSize(QSize(520,450));
  mainframe->setMaximumSize(QSize(520,450));

  QString temp1;
  temp1 = *treetab->GetFeature1(1);
  int pos=temp1.findRev(" ");
  int hm=temp1.length()-pos;
  temp1=temp1.right(hm-1);
  if (temp1 != QString("0")) 
      {
	temp1 += " - Component's Tree";
	mainframe->setCaption(temp1);

	closeb = new QPushButton(mainframe, "Close");
	refreshb = new QPushButton(mainframe, "Refresh");
	closeb->setText("Close");
	refreshb->setText("Refresh");
	closeb->setGeometry(2,2,45,25);
	refreshb->setGeometry(50, 2, 55, 25);
	connect(closeb,SIGNAL(pressed()),SLOT(closeButton()));
	connect(refreshb, SIGNAL(pressed()), SLOT(refreshButton()));
	
	classframe = new QFrame(mainframe, "frame");
	classframe->setGeometry(0,30,520,410);
	list = new QListView(classframe);
	list->addColumn("Variable Name");
	list->addColumn("Type");
	list->addColumn("Text");
	list->setGeometry(2,0,520,412);
	list->setFont(QFont("arial", 14));
	if (style == 0)
	    list->setStyle(WindowsStyle);
	else
	    list->setStyle(MotifStyle);
	QListViewItem *templist = new QListViewItem(list, "COMPONENT'S TREE:");
	templist->setOpen(TRUE);
	updateTreePic(treetab, templist);
	mainframe->show();
      }
  else
      closeButton();
}

void ShowTree::refreshButton()
{
  wx = mainframe->x();
  wy = mainframe->y();
  QFrame *old = mainframe;
  displayTree(FALSE);
  old->close();
}

void ShowTree::closeButton()
{
  mainframe->close();
}

